==> nextcloud-29.0.12.tgz: nextcloud/apps/workflowengine/l10n/ga.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Tá an t-oibreoir tugtha neamhbhailí",
    "The given regular expression is invalid" : "Tá an slonn rialta a thugtar neamhbhailí",
    "The given file size is invalid" : "Tá méid an chomhaid tugtha neamhbhailí",
    "The given tag id is invalid" : "Tá an t-aitheantas clibe tugtha neamhbhailí",
    "The given IP range is invalid" : "Tá an raon IP a thugtar neamhbhailí",
    "The given IP range is not valid for IPv4" : "Níl an raon IP tugtha bailí do IPv4",
    "The given IP range is not valid for IPv6" : "Níl an raon IP tugtha bailí do IPv6",
    "The given time span is invalid" : "Tá an tréimhse ama a thugtar neamhbhailí",
    "The given start time is invalid" : "Tá an t-am tosaithe tugtha neamhbhailí",
    "The given end time is invalid" : "Tá an t-am críochnaithe a thugtar neamhbhailí",
    "The given group does not exist" : "Níl an grúpa tugtha ann",
    "File" : "Comhad",
    "File created" : "Comhad cruthaithe",
    "File updated" : "Nuashonraíodh an comhad",
    "File renamed" : "Athainmníodh an comhad",
    "File deleted" : "Scriosadh an comhad",
    "File accessed" : "Teacht ar an gcomhad",
    "File copied" : "Cóipeáladh an comhad",
    "Tag assigned" : "Clib sannta",
    "Someone" : "Duine éigin",
    "%s created %s" : "%s cruthaithe %s",
    "%s modified %s" : "%s modhnaithe %s",
    "%s deleted %s" : "%s scriosta %s",
    "%s accessed %s" : "%s rochtain %s",
    "%s renamed %s" : "%s athainmnithe %s",
    "%s copied %s" : "%s chóipeáil %s",
    "%s assigned %s to %s" : "%s sannta %s do %s",
    "Operation #%s does not exist" : "Níl oibríocht # %s ann",
    "Entity %s does not exist" : "Níl aonán %s ann",
    "Entity %s is invalid" : "Tá aonán %s neamhbhailí",
    "No events are chosen." : "Ní roghnaítear aon imeachtaí.",
    "Entity %s has no event %s" : "Níl imeacht %s ag eintiteas %s",
    "Operation %s does not exist" : "Níl oibríocht %s ann",
    "Operation %s is invalid" : "Tá oibríocht %s neamhbhailí",
    "At least one check needs to be provided" : "Ní mór seiceáil amháin ar a laghad a sholáthar",
    "The provided operation data is too long" : "Tá na sonraí oibríochta a chuirtear ar fáil ró-fhada",
    "Invalid check provided" : "Cuireadh seiceáil neamhbhailí ar fáil",
    "Check %s does not exist" : "Seiceáil nach bhfuil %s ann",
    "Check %s is invalid" : "Seiceáil go bhfuil %s neamhbhailí",
    "Check %s is not allowed with this entity" : "Seiceáil nach bhfuil %s ceadaithe leis an eintiteas seo",
    "The provided check value is too long" : "Tá an luach seiceála a chuirtear ar fáil ró-fhada",
    "Check #%s does not exist" : "Seiceáil nach bhfuil # %s ann",
    "Check %s is invalid or does not exist" : "Seiceáil go bhfuil %s neamhbhailí nó níl sé ann",
    "Flow" : "Sreabhadh",
    "Nextcloud workflow engine" : "Inneall sreabhadh oibre Nextcloud",
    "Select a filter" : "Roghnaigh scagaire",
    "Select a comparator" : "Roghnaigh comparadóir",
    "Remove filter" : "Bain an scagaire",
    "Select a file type" : "Roghnaigh cineál comhaid",
    "e.g. httpd/unix-directory" : "m.sh. httpd/unix-directory",
    "Folder" : "Fillteán",
    "Images" : "Íomhánna",
    "Office documents" : "Doiciméid oifige",
    "PDF documents" : "Doiciméid PDF",
    "Custom MIME type" : "Cineál MIME saincheaptha",
    "Custom mimetype" : "Cineál MIME saincheaptha",
    "Please enter a valid time span" : "Cuir isteach réise ama bailí le do thoil",
    "Select a request URL" : "Roghnaigh URL iarratais",
    "Files WebDAV" : "Comhaid WebDAV",
    "Custom URL" : "URL saincheaptha",
    "Select a user agent" : "Roghnaigh gníomhaire úsáideora",
    "Android client" : "Cliant Android",
    "iOS client" : "Cliant iOS",
    "Desktop client" : "Cliant deisce",
    "Thunderbird & Outlook addons" : "Breiseáin Thunderbird agus Outlook",
    "Custom user agent" : "Gníomhaire úsáideora saincheaptha",
    "Select groups" : "Roghnaigh grúpaí",
    "Groups" : "Grúpaí",
    "Type to search for group …" : "Clóscríobh chun grúpa a chuardach…",
    "Select a trigger" : "Roghnaigh truicear",
    "At least one event must be selected" : "Ní mór imeacht amháin ar a laghad a roghnú",
    "Add new flow" : "Cuir sreabhadh nua leis",
    "When" : "Cathain",
    "and" : "agus",
    "Add a new filter" : "Cuir scagaire nua leis",
    "Cancel" : "Cealaigh",
    "Delete" : "Scrios",
    "The configuration is invalid" : "Tá an chumraíocht neamhbhailí",
    "Active" : "Gníomhach",
    "Save" : "Sábháil",
    "Available flows" : "Sreafaí ar fáil",
    "For details on how to write your own flow, check out the development documentation." : "Le sonraí a fháil faoi conas do shreabhadh féin a scríobh, seiceáil na doiciméid forbartha.",
    "No flows installed" : "Níl aon sreabhadh suiteáilte",
    "Ask your administrator to install new flows." : "Iarr ar do riarthóir sreafaí nua a shuiteáil.",
    "More flows" : "Níos mó sreafaí",
    "Browse the App Store" : "Brabhsáil an Siopa Aip",
    "Show less" : "Taispeáin níos lú",
    "Show more" : "Taispeáin níos mó",
    "Configured flows" : "Sreafaí cumraithe",
    "Your flows" : "Do shreabhadh",
    "No flows configured" : "Níl aon sreafaí cumraithe",
    "matches" : "oireann",
    "does not match" : "ní oireann",
    "is" : "tá",
    "is not" : "níl",
    "File name" : "Ainm comhaid",
    "File MIME type" : "Cineál comhaid MIME",
    "File size (upload)" : "Méid comhaid (uaslódáil)",
    "less" : "níos lú",
    "less or equals" : "níos lú nó comhionann",
    "greater or equals" : "níos mó nó comhionann",
    "greater" : "mó",
    "Request remote address" : "Iarr seoladh cianda",
    "matches IPv4" : "oireann IPv4",
    "does not match IPv4" : "ní mheaitseálann IPv4",
    "matches IPv6" : "meaitseálann IPv6",
    "does not match IPv6" : "Ní mheaitseálann IPv6",
    "File system tag" : "Clib córas comhaid",
    "is tagged with" : "Tá clib le",
    "is not tagged with" : "nach bhfuil clib le",
    "Request URL" : "Iarr URL",
    "Request time" : "Iarr am",
    "between" : "idir",
    "not between" : "ní idir",
    "Request user agent" : "Iarr gníomhaire úsáideora",
    "Group membership" : "Ballraíocht ghrúpa",
    "is member of" : "ina bhall de",
    "is not member of" : "nach ball de"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-31.0.10.tgz: nextcloud/apps/workflowengine/l10n/ga.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Tá an t-oibreoir tugtha neamhbhailí",
    "The given regular expression is invalid" : "Tá an slonn rialta a thugtar neamhbhailí",
    "The given file size is invalid" : "Tá méid an chomhaid tugtha neamhbhailí",
    "The given tag id is invalid" : "Tá an t-aitheantas clibe tugtha neamhbhailí",
    "The given IP range is invalid" : "Tá an raon IP a thugtar neamhbhailí",
    "The given IP range is not valid for IPv4" : "Níl an raon IP tugtha bailí do IPv4",
    "The given IP range is not valid for IPv6" : "Níl an raon IP tugtha bailí do IPv6",
    "The given time span is invalid" : "Tá an tréimhse ama a thugtar neamhbhailí",
    "The given start time is invalid" : "Tá an t-am tosaithe tugtha neamhbhailí",
    "The given end time is invalid" : "Tá an t-am críochnaithe a thugtar neamhbhailí",
    "The given group does not exist" : "Níl an grúpa tugtha ann",
    "File" : "Comhad",
    "File created" : "Comhad cruthaithe",
    "File updated" : "Nuashonraíodh an comhad",
    "File renamed" : "Athainmníodh an comhad",
    "File deleted" : "Scriosadh an comhad",
    "File accessed" : "Teacht ar an gcomhad",
    "File copied" : "Cóipeáladh an comhad",
    "Tag assigned" : "Clib sannta",
    "Someone" : "Duine éigin",
    "%s created %s" : "%s cruthaithe %s",
    "%s modified %s" : "%s modhnaithe %s",
    "%s deleted %s" : "%s scriosta %s",
    "%s accessed %s" : "%s rochtain %s",
    "%s renamed %s" : "%s athainmnithe %s",
    "%s copied %s" : "%s chóipeáil %s",
    "%s assigned %s to %s" : "%s sannta %s do %s",
    "Operation #%s does not exist" : "Níl oibríocht # %s ann",
    "Entity %s does not exist" : "Níl aonán %s ann",
    "Entity %s is invalid" : "Tá aonán %s neamhbhailí",
    "No events are chosen." : "Ní roghnaítear aon imeachtaí.",
    "Entity %s has no event %s" : "Níl imeacht %s ag eintiteas %s",
    "Operation %s does not exist" : "Níl oibríocht %s ann",
    "Operation %s is invalid" : "Tá oibríocht %s neamhbhailí",
    "At least one check needs to be provided" : "Ní mór seiceáil amháin ar a laghad a sholáthar",
    "The provided operation data is too long" : "Tá na sonraí oibríochta a chuirtear ar fáil ró-fhada",
    "Invalid check provided" : "Cuireadh seiceáil neamhbhailí ar fáil",
    "Check %s does not exist" : "Seiceáil nach bhfuil %s ann",
    "Check %s is invalid" : "Seiceáil go bhfuil %s neamhbhailí",
    "Check %s is not allowed with this entity" : "Seiceáil nach bhfuil %s ceadaithe leis an eintiteas seo",
    "The provided check value is too long" : "Tá an luach seiceála a chuirtear ar fáil ró-fhada",
    "Check #%s does not exist" : "Seiceáil nach bhfuil # %s ann",
    "Check %s is invalid or does not exist" : "Seiceáil go bhfuil %s neamhbhailí nó níl sé ann",
    "Flow" : "Sreabhadh",
    "Nextcloud workflow engine" : "Inneall sreabhadh oibre Nextcloud",
    "Select a filter" : "Roghnaigh scagaire",
    "Select a comparator" : "Roghnaigh comparadóir",
    "Remove filter" : "Bain an scagaire",
    "Audio" : "Fuaime",
    "Folder" : "Fillteán",
    "Images" : "Íomhánna",
    "Office documents" : "Doiciméid oifige",
    "PDF documents" : "Doiciméid PDF",
    "Video" : "Físeán",
    "Custom MIME type" : "Cineál MIME saincheaptha",
    "Custom mimetype" : "Cineál MIME saincheaptha",
    "Select a file type" : "Roghnaigh cineál comhaid",
    "e.g. httpd/unix-directory" : "m.sh. httpd/unix-directory",
    "Please enter a valid time span" : "Cuir isteach réise ama bailí le do thoil",
    "Files WebDAV" : "Comhaid WebDAV",
    "Custom URL" : "URL saincheaptha",
    "Select a request URL" : "Roghnaigh URL iarratais",
    "Android client" : "Cliant Android",
    "iOS client" : "Cliant iOS",
    "Desktop client" : "Cliant deisce",
    "Thunderbird & Outlook addons" : "Breiseáin Thunderbird agus Outlook",
    "Custom user agent" : "Gníomhaire úsáideora saincheaptha",
    "Select a user agent" : "Roghnaigh gníomhaire úsáideora",
    "Select groups" : "Roghnaigh grúpaí",
    "Groups" : "Grúpaí",
    "Type to search for group …" : "Clóscríobh chun grúpa a chuardach …",
    "Select a trigger" : "Roghnaigh truicear",
    "At least one event must be selected" : "Ní mór imeacht amháin ar a laghad a roghnú",
    "Add new flow" : "Cuir sreabhadh nua leis",
    "The configuration is invalid" : "Tá an chumraíocht neamhbhailí",
    "Active" : "Gníomhach",
    "Save" : "Sábháil",
    "When" : "Cathain",
    "and" : "agus",
    "Add a new filter" : "Cuir scagaire nua leis",
    "Cancel" : "Cealaigh",
    "Delete" : "Scrios",
    "Available flows" : "Sreafaí ar fáil",
    "For details on how to write your own flow, check out the development documentation." : "Le sonraí a fháil faoi conas do shreabhadh féin a scríobh, seiceáil na doiciméid forbartha.",
    "No flows installed" : "Níl aon sreabhadh suiteáilte",
    "Ask your administrator to install new flows." : "Iarr ar do riarthóir sreafaí nua a shuiteáil.",
    "More flows" : "Níos mó sreafaí",
    "Browse the App Store" : "Brabhsáil an Siopa Aip",
    "Show less" : "Taispeáin níos lú",
    "Show more" : "Taispeáin níos mó",
    "Configured flows" : "Sreafaí cumraithe",
    "Your flows" : "Do shreabhadh",
    "No flows configured" : "Níl aon sreafaí cumraithe",
    "matches" : "oireann",
    "does not match" : "ní oireann",
    "is" : "tá",
    "is not" : "níl",
    "File name" : "Ainm comhaid",
    "File MIME type" : "Cineál comhaid MIME",
    "File size (upload)" : "Méid comhaid (uaslódáil)",
    "less" : "níos lú",
    "less or equals" : "níos lú nó comhionann",
    "greater or equals" : "níos mó nó comhionann",
    "greater" : "mó",
    "Request remote address" : "Iarr seoladh cianda",
    "matches IPv4" : "oireann IPv4",
    "does not match IPv4" : "ní mheaitseálann IPv4",
    "matches IPv6" : "meaitseálann IPv6",
    "does not match IPv6" : "Ní mheaitseálann IPv6",
    "File system tag" : "Clib córas comhaid",
    "is tagged with" : "Tá clib le",
    "is not tagged with" : "nach bhfuil clib le",
    "Request URL" : "Iarr URL",
    "Request time" : "Iarr am",
    "between" : "idir",
    "not between" : "ní idir",
    "Request user agent" : "Iarr gníomhaire úsáideora",
    "Group membership" : "Ballraíocht ghrúpa",
    "is member of" : "ina bhall de",
    "is not member of" : "nach ball de",
    "Type to search for group …" : "Clóscríobh chun grúpa a chuardach…"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
